# SPDX-FileCopyrightText: 2018-2021 Bruce Cowan <bruce@bcowan.me.uk>
#
# SPDX-License-Identifier: GPL-3.0-or-later

import errbot
import pint
from pint import errors


class Unit(errbot.BotPlugin):
    """Commands which do unit conversions"""

    def activate(self):
        super().activate()

        self.ureg = pint.UnitRegistry()

    @errbot.botcmd
    def convert(self, message: errbot.Message, args: str) -> str:
        """Convert units"""
        if not args or " to " not in args:
            return "**Usage**: !convert <from> to <to>"

        src, dst = args.split(" to ")
        try:
            return f"{self.ureg(src).to(dst):~.4P}"
        except (errors.UndefinedUnitError, errors.PintTypeError) as e:
            return f"**Error**: {e!s}"

    @errbot.botcmd
    def si(self, message: errbot.Message, args: str) -> str:
        """Convert any value to base SI units"""
        if not args:
            return "**Usage**: !si <str>"

        try:
            return f"{self.ureg(args).to_base_units():~.4P}"
        except (errors.UndefinedUnitError, errors.PintTypeError) as e:
            return f"**Error**: {e!s}"
